@@ -14,27 +14,30 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 import abc
-import logging
 import sys
 import re
 
-from LMIUtil import lmi_cast_to_lmi
+from lmi.shell.LMIShellLogger import lmi_get_logger
+from lmi.shell.LMIUtil import lmi_cast_to_lmi
+
+logger = lmi_get_logger()
+
 
 class LMIConstantValues(object):
     """
     Abstract class for constant value objects.
 
-    :param cim_obj: this object is either of type :py:class:`CIMParameter`,
-        :py:class:`CIMProperty` or :py:class:`CIMMethod`. Construction of this
-        object requires to have a member ``_cast_type`` to properly cast CIM
-        object. When constructing derived objects, make sure, that the
-        mentioned member is present before calling this constructor.
+    :param cim_obj: this object is either of type
+        :py:class:`wbem.CIMParameter`, :py:class:`wbem.CIMProperty` or
+        :py:class:`wbem.CIMMethod`. Construction of this object requires to
+        have a member ``_cast_type`` to properly cast CIM object. When
+        constructing derived objects, make sure, that the mentioned member is
+        present before calling this constructor.
     :param cast_type: parameter/property cast type
     """
     __metaclass__ = abc.ABCMeta
 
     def __init__(self, cim_obj, cast_type):
-        logger = logging.getLogger(__name__)
         items = zip(
             cim_obj.qualifiers["Values"].value,
             cim_obj.qualifiers["ValueMap"].value)
@@ -43,7 +46,7 @@ class LMIConstantValues(object):
         self._cast_type = cast_type
         # Fill two dictionaries for bidirectional access to constant values.
         cnt = 1
-        for (key, value) in items:
+        for key, value in items:
             try:
                 # Cast constant value first. If we get ValueError, no key
                 # modifications are necessary.
@@ -57,7 +60,8 @@ class LMIConstantValues(object):
                 if mod_key in self._value_map:
                     mod_key += str(cnt)
                     cnt += 1
-                    logger.warn("Constant value mapped as: '%s' -> '%s'" % (key, mod_key))
+                    logger.warn("Constant value mapped as: '%s' -> '%s'" %
+                                (key, mod_key))
 
                 self._value_map[mod_key] = val
                 # For inverse mapping, we use unmodified key.
@@ -74,7 +78,7 @@ class LMIConstantValues(object):
         :returns: pretty string
         """
         result = ""
-        for (k, v) in self._value_map.iteritems():
+        for k, v in self._value_map.iteritems():
             result += "%s = %s\n" % (k, v)
         return result[:-1]
 
@@ -88,8 +92,6 @@ class LMIConstantValues(object):
         :param string name: member to retrieve
         :returns: class member
         """
-        if name in self.__dict__:
-            return self.__dict__[name]
         if name in self._value_map:
             return self._value_map[name]
         raise AttributeError(name)
@@ -134,23 +136,27 @@ class LMIConstantValues(object):
         """
         return self._value_map_inv[value]
 
+
 class LMIConstantValuesParamProp(LMIConstantValues):
     """
-    Derived class used for constant values of :py:class:`CIMProperty` and
-    :py:class:`CIMParameter`.
+    Derived class used for constant values of :py:class:`wbem.CIMProperty` and
+    :py:class:`wbem.CIMParameter`.
 
-    :param cim_property: :py:class:`CIMProperty` or :py:class:`CIMParameter`
-        object. Both objects have necessary member ``type`` which is needed for
-        proper casting.
+    :param cim_property: :py:class:`wbem.CIMProperty` or
+        :py:class:`wbem.CIMParameter` object. Both objects have necessary
+        member ``type`` which is needed for proper casting.
     """
     def __init__(self, cim_property):
-        super(LMIConstantValuesParamProp, self).__init__(cim_property, cim_property.type)
+        super(LMIConstantValuesParamProp, self).__init__(
+            cim_property, cim_property.type)
+
 
 class LMIConstantValuesMethodReturnType(LMIConstantValues):
     """
-    Derived class used for constant values of :py:class:`CIMMethod`.
+    Derived class used for constant values of :py:class:`wbem.CIMMethod`.
 
-    :param CIMMethod cim_method: :py:class:`CIMMethod` object
+    :param CIMMethod cim_method: :py:class:`wbem.CIMMethod` object
     """
     def __init__(self, cim_method):
-        super(LMIConstantValuesMethodReturnType, self).__init__(cim_method, cim_method.return_type)
+        super(LMIConstantValuesMethodReturnType, self).__init__(
+            cim_method, cim_method.return_type)
