@@ -13,62 +13,78 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
+
 class LMIDeletedObjectError(Exception):
     """
     Raised, when there is an attempt to access properties on deleted
-    :py:class:`LMIInstance` object.
+    :py:class:`.LMIInstance` object.
     """
 
+
 class LMIUnknownParameterError(Exception):
     """
-    Raised, when there is a method call issued and unknown method parameter is provided.
+    Raised, when there is a method call issued and unknown method parameter is
+    provided.
     """
 
+
 class LMIUnknownPropertyError(Exception):
     """
-    Raised, when there is an attempt to create instance with unknown property provided.
+    Raised, when there is an attempt to create instance with unknown property
+    provided.
     """
 
+
 class LMIMethodCallError(Exception):
     """
     Raised, when an error occurs within method call.
     """
 
+
 class LMISynchroMethodCallError(Exception):
     """
     Raised, when an error occurs within synchronized method call.
     """
 
+
 class LMISynchroMethodCallFilterError(Exception):
     """
-    Raised, when the LMIShell can not find necessary static filter for synchronous method call.
+    Raised, when the LMIShell can not find necessary static filter for
+    synchronous method call.
     """
 
+
 class LMINoPagerError(Exception):
     """
     Raised, when there is no default pager like less or more.
     """
 
+
 class LMIIndicationError(Exception):
     """
     Raised, if an error occurs while subscribing to/removing an indication.
     """
 
+
 class LMIIndicationListenerError(Exception):
     """
     Raised, if there is an error while starting/stopping indication listener.
     """
 
+
 class LMIHandlerNamePatternError(Exception):
     """
-    Raised when the pattern string does not contain minimum replaceable characters.
+    Raised when the pattern string does not contain minimum replaceable
+    characters.
     """
 
+
 class LMIFilterError(Exception):
     """
     Raised, when a filter error occurs, mostly when filter object is missing.
     """
 
+
 class LMIClassNotFound(AttributeError):
     """
     Raised, when trying to access missing class in LMINamespace.
@@ -77,18 +93,48 @@ class LMIClassNotFound(AttributeError):
     :param string classname: class name, which was not found in **namespace**
     """
     def __init__(self, namespace, class_name):
-        AttributeError.__init__(self, 'no such class "%s" in "%s" namespace' %
-                (class_name, namespace))
+        AttributeError.__init__(
+            self, 'no such class "%s" in "%s" namespace' %
+            (class_name, namespace))
+
 
 class LMINamespaceNotFound(AttributeError):
     """
-    Raised, when trying to access not existing namespace from connection
-    or namespace object.
+    Raised, when trying to access not existing namespace from connection or
+    namespace object.
 
     :param string namespace: namespace which was not found
     :param args: other positional arguments
     """
     def __init__(self, namespace, *args):
         AttributeError.__init__(self, 'no such namespace "%s"' %
-                "/".join([namespace] + list(args)))
+                                "/".join([namespace] + list(args)))
 
+
+class LMINotSupported(Exception):
+    """
+    Raised, when non-WSMAN method is about to be called.
+    """
+
+
+class CIMError(Exception):
+    """
+    LMIShell's exception for CIM errors.
+    """
+    def __init__(self, *args):
+        super(CIMError, self).__init__()
+        if len(args) == 1 and isinstance(args[0], Exception):
+            self.args = args[0].args
+        else:
+            self.args = args
+
+class ConnectionError(Exception):
+    """
+    LMIShell's exception for Connection errors.
+    """
+    def __init__(self, *args):
+        super(ConnectionError, self).__init__()
+        if len(args) == 1 and isinstance(args[0], Exception):
+            self.args = args[0].args
+        else:
+            self.args = args
