@@ -17,12 +17,12 @@ import sys
 
 import LMIExceptions
 
-from LMIBaseObject import LMIWrapperBaseObject
-from LMIBaseClient import LMIBaseClient
+from lmi.shell.LMIBaseObject import LMIWrapperBaseObject
+
+from lmi.shell.LMIUtil import lmi_wrap_cim_namespace
+from lmi.shell.LMIUtil import lmi_wrap_cim_class
+from lmi.shell.LMIUtil import lmi_transform_to_lmi
 
-from LMIUtil import lmi_wrap_cim_namespace
-from LMIUtil import lmi_wrap_cim_class
-from LMIUtil import lmi_transform_to_lmi
 
 class LMINamespace(LMIWrapperBaseObject):
     """
@@ -37,13 +37,11 @@ class LMINamespace(LMIWrapperBaseObject):
 
     def __getattr__(self, name):
         """
-        Returns a :py:class:`LMIClass` object.
+        Returns a :py:class:`.LMIClass` object.
 
         :param string name: class name
-        :returns: :py:class:`LMIClass` object
+        :returns: :py:class:`.LMIClass` object
         """
-        if name in self.__dict__:
-            return self.__dict__[name]
         return lmi_wrap_cim_class(self._conn, name, self.name)
 
     def __repr__(self):
@@ -52,27 +50,22 @@ class LMINamespace(LMIWrapperBaseObject):
         """
         return "%s(namespace='%s', ...)" % (self.__class__.__name__, self.name)
 
-    def classes(self, filter_key="", exact_match=False):
+    def classes(self):
         """
         Returns a list of class names.
 
         :param string filter_key: substring of a class name
-        :param bool exact_match: tells, if to search for exact match or substring
+        :param bool exact_match: tells, if to search for exact match or
+            substring
         :returns: list of class names
 
         **Usage:** :ref:`namespaces_available_classes`.
         """
-        (class_name_list, _, errorstr) = self._conn._client._get_class_names(
+        class_names, _, errorstr = self._conn.client.get_class_names(
             self._name, DeepInheritance=True)
-        if not class_name_list:
+        if not class_names:
             return []
-        if filter_key:
-            if not exact_match:
-                filter_lambda = lambda n: n.lower().find(filter_key.lower()) >= 0
-            else:
-                filter_lambda = lambda n: n.lower() == filter_key.lower()
-            class_name_list = filter(filter_lambda, class_name_list)
-        return class_name_list
+        return class_names
 
     def get_class(self, classname):
         """
@@ -81,51 +74,55 @@ class LMINamespace(LMIWrapperBaseObject):
         :param string classname: class name of new :py:class:`.LMIClass`
         :raises: :py:exc:`.LMIClassNotFound`
         """
-        (class_list, _, _) = self._conn._client._get_class_names(self._name,
-            DeepInheritance=True)
-        if classname in class_list:
+        class_names, _, _ = self._conn.client.get_class_names(
+            self._name, DeepInheritance=True)
+        if class_names is not None and classname in class_names:
             return lmi_wrap_cim_class(self._conn, classname, self.name)
         raise LMIExceptions.LMIClassNotFound(self.name, classname)
 
-    def print_classes(self, filter_key="", exact_match=False):
+    def print_classes(self):
         """
         Prints out a list of classes.
 
         :param string filter_key: substring of a class name
-        :param bool exact_match: tells, if to search for exact match, or to search for a
-            matching substring
+        :param bool exact_match: tells, if to search for exact match, or to
+            search for a matching substring
 
         **Usage:** :ref:`namespaces_available_classes`.
         """
-        for c in self.classes(filter_key, exact_match):
+        for c in self.classes():
             sys.stdout.write("%s\n" % c)
 
     def cql(self, query):
         """
-        Executes a CQL query and returns a list of :py:class:`LMIInstance` objects.
+        Executes a CQL query and returns a list of :py:class:`.LMIInstance`
+        objects.
 
         :param string query: CQL query to execute
-        :returns: :py:class:`LMIReturnValue` object with ``rval`` set to a list
-            of :py:class:`LMIInstance` objects
+        :returns: :py:class:`.LMIReturnValue` object with ``rval`` set to a
+            list of :py:class:`.LMIInstance` objects
 
         **Usage:** :ref:`namespaces_queries`.
         """
-        (inst_list, _, errorstr) = self._conn._client._exec_query(LMIBaseClient.QUERY_LANG_CQL, query, self._name)
+        inst_list, _, errorstr = self._conn.client.exec_query(
+            self._conn.client.QUERY_LANG_CQL, query, self._name)
         if not inst_list:
             return []
         return lmi_transform_to_lmi(self._conn, inst_list)
 
     def wql(self, query):
         """
-        Executes a WQL query and returns a list of :py:class:`LMIInstance` objects.
+        Executes a WQL query and returns a list of :py:class:`.LMIInstance`
+        objects.
 
         :param string query: WQL query to execute
-        :returns: :py:class:`LMIReturnValue` object with ``rval`` set to a list
-            of :py:class:`LMIInstance` objects
+        :returns: :py:class:`.LMIReturnValue` object with ``rval`` set to a
+            list of :py:class:`.LMIInstance` objects
 
         **Usage:** :ref:`namespaces_queries`.
         """
-        (inst_list, _, errorstr) = self._conn._client._exec_query(LMIBaseClient.QUERY_LANG_WQL, query, self._name)
+        inst_list, _, errorstr = self._conn.client.exec_query(
+            self._conn.client.QUERY_LANG_WQL, query, self._name)
         if not inst_list:
             return []
         return lmi_transform_to_lmi(self._conn, inst_list)
@@ -138,47 +135,29 @@ class LMINamespace(LMIWrapperBaseObject):
         """
         return self._name
 
+
 class LMINamespaceRoot(LMINamespace):
     """
-    Derived class for *root* namespace. Object of this class is accessible
-    from :py:class:`LMIConnection` object as a hierarchy entry.
+    Derived class for *root* namespace. Object of this class is accessible from
+    :py:class:`.LMIConnection` object as a hierarchy entry.
 
     :param LMIConnection conn: connection object
     """
+    _SUPPORTED_NAMESPACES = [
+        "cimv2",
+        "dcim",
+        "interop",
+        "PG_InterOp",
+        "PG_Internal"
+    ]
+
     def __init__(self, conn):
         super(LMINamespaceRoot, self).__init__(conn, "root")
 
-    @property
-    def cimv2(self):
-        """
-        :returns: *root/cimv2* namespace
-        :rtype: :py:class:`LMINamespace`
-        """
-        return lmi_wrap_cim_namespace(self._conn, "root/cimv2")
-
-    @property
-    def interop(self):
-        """
-        :returns: *root/interop* namespace
-        :rtype: :py:class:`LMINamespace`
-        """
-        return lmi_wrap_cim_namespace(self._conn, "root/interop")
-
-    @property
-    def PG_InterOp(self):
-        """
-        :returns: *root/PG_InterIp* namespace
-        :rtype: :py:class:`LMINamespace`
-        """
-        return lmi_wrap_cim_namespace(self._conn, "root/PG_InterOp")
-
-    @property
-    def PG_Internal(self):
-        """
-        :returns: *root/PG_Internal* namespace
-        :rtype: :py:class:`LMINamespace`
-        """
-        return lmi_wrap_cim_namespace(self._conn, "root/PG_Internal")
+    def __getattr__(self, name):
+        if name in LMINamespaceRoot._SUPPORTED_NAMESPACES:
+            return lmi_wrap_cim_namespace(self._conn, "root/" + name)
+        raise AttributeError(name)
 
     @property
     def namespaces(self):
@@ -187,15 +166,14 @@ class LMINamespaceRoot(LMINamespace):
 
         **Usage:** :ref:`namespaces_available_namespaces`.
         """
-        return ["cimv2", "interop", "PG_InterOp", "PG_Internal"]
+        return LMINamespaceRoot._SUPPORTED_NAMESPACES
 
     def print_namespaces(self):
         """
-        Prints out all available namespaces accessible via the namespace `root`.
+        Prints out all available namespaces accessible via the namespace
+        `root`.
 
         **Usage:** :ref:`namespaces_available_namespaces`.
         """
-        sys.stdout.write("cimv2\n")
-        sys.stdout.write("interop\n")
-        sys.stdout.write("PG_InterOp\n")
-        sys.stdout.write("PG_Internal\n")
+        for ns in LMINamespaceRoot._SUPPORTED_NAMESPACES:
+            sys.stdout.write("%s\n" % ns)
